colour.plotting.temperature Module — Colour 0.3.0 documentation

# colour.plotting.temperature Module

## Colour Temperature & Correlated Colour Temperature Plotting

Defines the colour temperature and correlated colour temperature plotting objects:

- `planckian_locus_CIE_1931_chromaticity_diagram_plot()`
- `planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot()`

`colour.plotting.temperature.` `planckian_locus_CIE_1931_chromaticity_diagram_plot`(*args, **kwargs)

  Plots the planckian locus and given illuminants in CIE 1931 Chromaticity Diagram.

  Parameters: | illuminants (array_like, optional) – Factory illuminants to plot. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool
  Raises: | `KeyError` – If one of the given illuminant is not found in the factory illuminants.

  Examples

      >>> ils = ['A', 'B', 'C']
      >>> planckian_locus_CIE_1931_chromaticity_diagram_plot(ils)
      True

`colour.plotting.temperature.` `planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot`(*args, **kwargs)

  Plots the planckian locus and given illuminants in CIE 1960 UCS Chromaticity Diagram.

  Parameters: | illuminants (array_like, optional) – Factory illuminants to plot. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool
  Raises: | `KeyError` – If one of the given illuminant is not found in the factory illuminants.

  Examples

      >>> ils = ['A', 'C', 'E']
      >>> planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot(ils)
      True